/* ----------------------------------------------------------------------------
  f2cad: Convert Fortran to C++ AD Types: Copyright (C) 2005-10 Bradley M. Bell
  Authors:  Bradley M. Bell    bradbell at washington dot edu
  License:  GNU Public License Version 2 or higher
-----------------------------------------------------------------------------*/

/*
$begin initds$$
$spell
	hpp
	cmlib
	initds
	bool
	sizeof
	blas
	doublereal
$$

$section  initds$$

$index cmlib, initds$$
$index initds, cmlib$$

$head Prototype$$
$include p.omh/initds.p.omh$$

$children%
	omh/initds.f.omh
%$$
$head Fortran Source$$
$cref initds.f$$

$head Description$$
This example uses the routine 
$codei%initds.f%$$ to compute the minimum value of $icode m$$ such that
$latex \[
	\sum_{i=m}^{i=n} | a_i | \leq \eta
\] $$
Note that there are $icode m$$ terms in the rest of the summation; i.e.,
$latex \[
	\sum_{i=1}^{m-1} a_i
\] $$

$codep */

# include <f2cad/initds.hpp>

test_result initds(void)
{	bool ok = true;

	//                   a_0,  a_1,  a_2,  a_3,  a_4,  a_5
	doublereal a[]   = { 1e0, 1e-1, 1e-2, 1e-3, 1e-4, 1e-5};
	integer    n     = sizeof(a) / sizeof(a[0]);
	doublereal eta   = 1e-3;
	integer    m     = f2cad::initds_(a, &n, &eta);
	
	ok &= (m == 4);

	if( ok )
		return test_pass;
	return test_fail;
}
/* $$
$end
*/
